Package: ACNE
Version: 0.9.2
Depends: R (>= 3.0.0), aroma.affymetrix (>= 2.14.0)
Imports: MASS, R.methodsS3 (>= 1.7.0), R.oo (>= 1.23.0), R.utils (>=
        2.1.0), matrixStats (>= 0.50.0), R.filesets (>= 2.9.0),
        aroma.core (>= 2.14.0)
Suggests: DNAcopy
Title: Affymetrix SNP Probe-Summarization using Non-Negative Matrix
        Factorization
Authors@R: c(
  person("Maria", "Ortiz", role=c("aut")),
  person("Henrik", "Bengtsson", role=c("aut", "cre", "cph"),
                                 email="henrikb@braju.com"),
  person("Angel", "Rubio", role=c("aut")))
Description: A summarization method to estimate allele-specific copy number signals for Affymetrix SNP microarrays using non-negative matrix factorization (NMF).
License: LGPL (>= 2.1)
URL: https://github.com/HenrikBengtsson/ACNE
BugReports: https://github.com/HenrikBengtsson/ACNE/issues
LazyLoad: TRUE
biocViews: aCGH, CopyNumberVariants, SNP, Microarray, OneChannel,
        TwoChannel, Genetics
NeedsCompilation: no
Packaged: 2025-08-19 17:11:26 UTC; hb
Author: Maria Ortiz [aut],
  Henrik Bengtsson [aut, cre, cph],
  Angel Rubio [aut]
Maintainer: Henrik Bengtsson <henrikb@braju.com>
Repository: CRAN
Date/Publication: 2025-08-19 17:40:07 UTC
Built: R 4.6.0; ; 2026-04-29 09:42:21 UTC; unix
