

<div id="badges"><!-- pkgdown markup -->
<a href="https://CRAN.R-project.org/web/checks/check_results_ACNE.html"><img border="0" src="https://www.r-pkg.org/badges/version/ACNE" alt="CRAN check status"/></a> <a href="https://github.com/HenrikBengtsson/ACNE/actions?query=workflow%3AR-CMD-check"><img border="0" src="https://github.com/HenrikBengtsson/ACNE/actions/workflows/R-CMD-check.yaml/badge.svg?branch=develop" alt="R CMD check status"/></a>     <a href="https://app.codecov.io/gh/HenrikBengtsson/ACNE"><img border="0" src="https://codecov.io/gh/HenrikBengtsson/ACNE/branch/develop/graph/badge.svg" alt="Coverage Status"/></a> 
</div>

# ACNE: Affymetrix SNP Probe-Summarization using Non-Negative Matrix Factorization 


## Installation
R package ACNE is available on [CRAN](https://cran.r-project.org/package=ACNE) and can be installed in R as:
```r
install.packages("ACNE")
```


### Pre-release version

To install the pre-release version that is available in Git branch `develop` on GitHub, use:
```r
remotes::install_github("HenrikBengtsson/ACNE", ref="develop")
```
This will install the package from source.  

<!-- pkgdown-drop-below -->

